;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "acp" "20260503.1851"
  "An ACP (Agent Client Protocol) implementation."
  '((emacs "28.1"))
  :url "https://github.com/xenodium/acp.el"
  :commit "03099fa0d0b669c91124880d71e1d5abecd83add"
  :revdesc "03099fa0d0b6")
